@@ -19,9 +19,11 @@ module Gitlab
     include ContainerRegistry
     include Deployments
     include Environments
+    include EpicIssues
     include Epics
     include Events
     include Features
+    include GroupBadges
     include GroupBoards
     include GroupLabels
     include GroupMilestones
@@ -51,6 +53,7 @@ module Gitlab
     include RepositoryFiles
     include RepositorySubmodules
     include ResourceLabelEvents
+    include ResourceStateEvents
     include Runners
     include Search
     include Services
@@ -61,6 +64,7 @@ module Gitlab
     include Templates
     include Todos
     include Users
+    include UserSnippets
     include Versions
     include Wikis
 
@@ -78,7 +82,7 @@ module Gitlab
     #
     # @return [String]
     def url_encode(url)
-      url.to_s.b.gsub(/[^a-zA-Z0-9_\-.~]/n) { |m| sprintf('%%%02X', m.unpack1('C')) } # rubocop:disable Style/FormatString, Style/FormatStringToken
+      url.to_s.b.gsub(/[^a-zA-Z0-9_\-.~]/n) { |m| sprintf('%%%02X', m.unpack1('C')) } # rubocop:disable Style/FormatString
     end
 
     private
