@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class Gitlab::Client
   # Defines methods related to repositories.
   # @see https://docs.gitlab.com/ce/api/branches.html
@@ -12,10 +14,10 @@ class Gitlab::Client
     # @option options [Integer] :page The page number.
     # @option options [Integer] :per_page The number of results per page.
     # @return [Array<Gitlab::ObjectifiedHash>]
-    def branches(project, options={})
+    def branches(project, options = {})
       get("/projects/#{url_encode project}/repository/branches", query: options)
     end
-    alias_method :repo_branches, :branches
+    alias repo_branches branches
 
     # Gets information about a repository branch.
     #
@@ -29,7 +31,7 @@ class Gitlab::Client
     def branch(project, branch)
       get("/projects/#{url_encode project}/repository/branches/#{url_encode branch}")
     end
-    alias_method :repo_branch, :branch
+    alias repo_branch branch
 
     # Protects a repository branch.
     #
@@ -47,9 +49,9 @@ class Gitlab::Client
     # @option options [Boolean] :developers_can_merge True to allow developers to merge into the branch (default = false)
     # @return [Gitlab::ObjectifiedHash] Details about the branch
     def protect_branch(project, branch, options = {})
-      post("/projects/#{url_encode project}/protected_branches", body: {name: branch}.merge(options))
+      post("/projects/#{url_encode project}/protected_branches", body: { name: branch }.merge(options))
     end
-    alias_method :repo_protect_branch, :protect_branch
+    alias repo_protect_branch protect_branch
 
     # Unprotects a repository branch.
     #
@@ -63,7 +65,7 @@ class Gitlab::Client
     def unprotect_branch(project, branch)
       delete("/projects/#{url_encode project}/protected_branches/#{url_encode branch}")
     end
-    alias_method :repo_unprotect_branch, :unprotect_branch
+    alias repo_unprotect_branch unprotect_branch
 
     # Creates a repository branch.  Requires Gitlab >= 6.8.x
     #
@@ -78,7 +80,7 @@ class Gitlab::Client
     def create_branch(project, branch, ref)
       post("/projects/#{url_encode project}/repository/branches", query: { branch: branch, ref: ref })
     end
-    alias_method :repo_create_branch, :create_branch
+    alias repo_create_branch create_branch
 
     # Deletes a repository branch.  Requires Gitlab >= 6.8.x
     #
@@ -91,6 +93,43 @@ class Gitlab::Client
     def delete_branch(project, branch)
       delete("/projects/#{url_encode project}/repository/branches/#{url_encode branch}")
     end
-    alias_method :repo_delete_branch, :delete_branch
+    alias repo_delete_branch delete_branch
+
+    # Delete all branches that are merged into the project default branch. Protected branches will not be deleted as part of this operation.
+    #
+    # @example
+    #   Gitlab.delete_merged_branches(3)
+    #
+    # @param  [Integer, String] project The ID or name of a project.
+    # @return [nil] This API call returns an empty response body.
+    def delete_merged_branches(project)
+      delete("/projects/#{url_encode project}/repository/merged_branches")
+    end
+    alias repo_delete_merged_branches delete_merged_branches
+
+    # Gets a list of protected branches from a project.
+    #
+    # @example
+    #   Gitlab.protected_branches(42)
+    #
+    # @param  [Integer, String] project The ID or name of a project.
+    # @return [Array<Gitlab::ObjectifiedHash>]
+    def protected_branches(project)
+      get("/projects/#{url_encode project}/protected_branches")
+    end
+    alias repo_protected_branches protected_branches
+
+    # Gets a single protected branch or wildcard protected branch
+    #
+    # @example
+    #   Gitlab.protected_branch(3, 'api')
+    #
+    # @param  [Integer, String] project The ID or name of a project.
+    # @param  [String] name The name of the branch or wildcard
+    # @return [Gitlab::ObjectifiedHash]
+    def protected_branch(project, branch)
+      get("/projects/#{url_encode project}/protected_branches/#{url_encode branch}")
+    end
+    alias repo_protected_branch protected_branch
   end
 end
