@@ -24,9 +24,12 @@ class Gitlab::Client
     #   Gitlab.group(42)
     #
     # @param  [Integer] id The ID of a group.
+    # @param  [Hash] options A customizable set of options.
+    # @option options [Boolean] :with_custom_attributes Include custom attributes in response (admins only)
+    # @option options [Boolean] :with_projects Include details about group projects (default: true)
     # @return [Gitlab::ObjectifiedHash]
-    def group(id)
-      get("/groups/#{url_encode id}")
+    def group(id, options = {})
+      get("/groups/#{url_encode id}", query: options)
     end
 
     # Creates a new group.
@@ -68,6 +71,21 @@ class Gitlab::Client
       get("/groups/#{url_encode id}/members", query: options)
     end
 
+    # Get a list of group members that are billable.
+    #
+    # @example
+    #   Gitlab.group_billable_members(1)
+    #   Gitlab.group_billable_members(1, { per_page: 40 })
+    #
+    # @param  [Integer] id The ID of a group.
+    # @param  [Hash] options A customizable set of options.
+    # @option options [Integer] :page The page number.
+    # @option options [Integer] :per_page The number of results per page.
+    # @return [Array<Gitlab::ObjectifiedHash>]
+    def group_billable_members(id, options = {})
+      get("/groups/#{url_encode id}/billable_members", query: options)
+    end
+
     # Get details of a single group member.
     #
     # @example
@@ -80,6 +98,18 @@ class Gitlab::Client
       get("/groups/#{url_encode team_id}/members/#{user_id}")
     end
 
+    # Gets a list of merge requests of a group.
+    #
+    # @example
+    #   Gitlab.group_merge_requests(5)
+    #
+    # @param  [Integer, String] group_id The ID or name of a group.
+    # @param  [Hash] options A customizable set of options.
+    # @return [Array<Gitlab::ObjectifiedHash>]
+    def group_merge_requests(group, options = {})
+      get("/groups/#{group}/merge_requests", query: options)
+    end
+
     # Adds a user to group.
     #
     # @example
@@ -191,5 +221,54 @@ class Gitlab::Client
     def edit_group(id, options = {})
       put("/groups/#{url_encode id}", body: options)
     end
+
+    # Gets a list of issues of a group.
+    #
+    # @example
+    #   Gitlab.group_issues(5)
+    #
+    # @param  [Integer, String] group_id The ID or name of a group.
+    # @param  [Hash] options A customizable set of options.
+    # @return [Array<Gitlab::ObjectifiedHash>]
+    def group_issues(group, options = {})
+      get("/groups/#{group}/issues", query: options)
+    end
+
+    # Sync group with LDAP
+    #
+    # @example
+    #   Gitlab.sync_ldap_group(1)
+    #
+    # @param [Integer] id The ID or name of a group.
+    # @return [Array<Gitlab::ObjectifiedHash>]
+    def sync_ldap_group(id)
+      post("/groups/#{url_encode id}/ldap_sync")
+    end
+
+    # Add LDAP group link
+    #
+    # @example
+    #   Gitlab.add_ldap_group_links(1, 'all', 50, 'ldap')
+    #
+    # @param  [Integer] id The ID of a group
+    # @param  [String] cn The CN of a LDAP group
+    # @param  [Integer] group_access Minimum access level for members of the LDAP group.
+    # @param  [String] provider LDAP provider for the LDAP group
+    # @return [Gitlab::ObjectifiedHash] Information about added ldap group link
+    def add_ldap_group_links(id, commonname, group_access, provider)
+      post("/groups/#{url_encode id}/ldap_group_links", body: { cn: commonname, group_access: group_access, provider: provider })
+    end
+
+    # Delete LDAP group link
+    #
+    # @example
+    #   Gitlab.delete_ldap_group_links(1, 'all')
+    #
+    # @param  [Integer] id The ID of a group
+    # @param  [String] cn The CN of a LDAP group
+    # @return [Gitlab::ObjectifiedHash] Empty hash
+    def delete_ldap_group_links(id, commonname, provider)
+      delete("/groups/#{url_encode id}/ldap_group_links/#{url_encode provider}/#{url_encode commonname}")
+    end
   end
 end
