@@ -13,7 +13,8 @@ class Gitlab::Client
     # @param  [Integer, String] project The ID or name of a project.
     # @param  [Hash] options A customizable set of options.
     # @option options [String] :path The path inside repository.
-    # @option options [String] :ref_name The name of a repository branch or tag.
+    # @option options [String] :ref The name of a repository branch or tag.
+    # @option options [Integer] :per_page Number of results to show per page (default = 20)
     # @return [Gitlab::ObjectifiedHash]
     def tree(project, options = {})
       get("/projects/#{url_encode project}/repository/tree", query: options)
@@ -28,9 +29,10 @@ class Gitlab::Client
     #
     # @param  [Integer, String] project The ID or name of a project.
     # @param  [String] ref The commit sha, branch, or tag to download.
+    # @param  [String] format The archive format. Options are: tar.gz (default), tar.bz2, tbz, tbz2, tb2, bz2, tar, and zip
     # @return [Gitlab::FileResponse]
-    def repo_archive(project, ref = 'master')
-      get("/projects/#{url_encode project}/repository/archive",
+    def repo_archive(project, ref = 'master', format = 'tar.gz')
+      get("/projects/#{url_encode project}/repository/archive.#{format}",
           format: nil,
           headers: { Accept: 'application/octet-stream' },
           query: { sha: ref },
@@ -70,5 +72,21 @@ class Gitlab::Client
     def merge_base(project, refs)
       get("/projects/#{url_encode project}/repository/merge_base", query: { refs: refs })
     end
+
+    # Get project repository contributors.
+    #
+    # @example
+    #   Gitlab.contributors(42)
+    #   Gitlab.contributors(42, { order: 'name' })
+    #
+    # @param  [Integer, String] project The ID or name of a project.
+    # @param  [Hash] options A customizable set of options.
+    # @option options [String] :order_by Order by name, email or commits (default = commits).
+    # @option options [String] :sort Sort order asc or desc (default = asc).
+    # @return [Array<Gitlab::ObjectifiedHash>]
+    def contributors(project, options = {})
+      get("/projects/#{url_encode project}/repository/contributors", query: options)
+    end
+    alias repo_contributors contributors
   end
 end
