@@ -7,7 +7,7 @@ module Gitlab
   class PageLinks
     HEADER_LINK = 'Link'
     DELIM_LINKS = ','
-    LINK_REGEX = /<([^>]+)>; rel=\"([^\"]+)\"/.freeze
+    LINK_REGEX = /<([^>]+)>; rel="([^"]+)"/.freeze
     METAS = %w[last next first prev].freeze
 
     attr_accessor(*METAS)
