@@ -8,7 +8,7 @@ describe Gitlab::Client do
       stub_get('/runners', 'runners')
     end
 
-    context 'without scope' do
+    context 'without extra queries' do
       before do
         @runner = Gitlab.runners
       end
@@ -24,14 +24,14 @@ describe Gitlab::Client do
       end
     end
 
-    context 'with scope' do
+    context 'with queries' do
       before do
-        stub_get('/runners?scope=online', 'runners')
-        @runner = Gitlab.runners(scope: :online)
+        stub_get('/runners?type=instance_type', 'runners')
+        @runner = Gitlab.runners(type: :instance_type)
       end
 
       it 'gets the correct resource' do
-        expect(a_get('/runners').with(query: { scope: :online })).to have_been_made
+        expect(a_get('/runners').with(query: { type: :instance_type })).to have_been_made
       end
 
       it 'returns a paginated response of runners' do
@@ -47,7 +47,7 @@ describe Gitlab::Client do
       stub_get('/runners/all', 'runners')
     end
 
-    context 'without scope' do
+    context 'without extra queries' do
       before do
         @runner = Gitlab.all_runners
       end
@@ -63,14 +63,14 @@ describe Gitlab::Client do
       end
     end
 
-    context 'with scope' do
+    context 'with queries' do
       before do
-        stub_get('/runners/all?scope=online', 'runners')
-        @runner = Gitlab.all_runners(scope: :online)
+        stub_get('/runners/all?type=instance_type', 'runners')
+        @runner = Gitlab.all_runners(type: :instance_type)
       end
 
       it 'gets the correct resource' do
-        expect(a_get('/runners/all').with(query: { scope: :online })).to have_been_made
+        expect(a_get('/runners/all').with(query: { type: :instance_type })).to have_been_made
       end
 
       it 'returns a paginated response of runners' do
@@ -100,12 +100,12 @@ describe Gitlab::Client do
 
   describe '.update_runner' do
     before do
-      stub_put('/runners/6', 'runner_edit').with(query: { description: 'abcefg' })
+      stub_put('/runners/6', 'runner_edit').with(body: { description: 'abcefg' })
       @runner = Gitlab.update_runner(6, description: 'abcefg')
     end
 
     it 'gets the correct resource' do
-      expect(a_put('/runners/6').with(query: { description: 'abcefg' })).to have_been_made
+      expect(a_put('/runners/6').with(body: { description: 'abcefg' })).to have_been_made
     end
 
     it 'returns an updated response of a runner' do
@@ -132,12 +132,12 @@ describe Gitlab::Client do
 
   describe '.runner_jobs' do
     before do
-      stub_get('/runners/1/jobs', 'runner_jobs')
-      @jobs = Gitlab.runner_jobs(1)
+      stub_get('/runners/1/jobs?status=running', 'runner_jobs')
+      @jobs = Gitlab.runner_jobs(1, status: :running)
     end
 
     it 'gets the correct resource' do
-      expect(a_get('/runners/1/jobs')).to have_been_made
+      expect(a_get('/runners/1/jobs').with(query: { status: :running })).to have_been_made
     end
   end
 
@@ -191,4 +191,79 @@ describe Gitlab::Client do
       expect(@runner.description).to eq('test-1-20150125')
     end
   end
+
+  describe '.group_runners' do
+    before do
+      stub_get('/groups/9/runners', 'group_runners')
+    end
+
+    context 'without extra queries' do
+      before do
+        @runners = Gitlab.group_runners(9)
+      end
+
+      it 'gets the correct resource' do
+        expect(a_get('/groups/9/runners')).to have_been_made
+      end
+
+      it 'returns a paginated response of runners' do
+        expect(@runners).to be_a Gitlab::PaginatedResponse
+      end
+    end
+
+    context 'with queries' do
+      before do
+        stub_get('/groups/9/runners?type=instance_type', 'group_runners')
+        @runner = Gitlab.group_runners(9, type: :instance_type)
+      end
+
+      it 'gets the correct resource' do
+        expect(a_get('/groups/9/runners').with(query: { type: :instance_type })).to have_been_made
+      end
+
+      it 'returns a paginated response of runners' do
+        expect(@runner).to be_a Gitlab::PaginatedResponse
+      end
+    end
+  end
+
+  describe '.register_runner' do
+    before do
+      stub_post('/runners', 'register_runner_response').with(body: { token: '6337ff461c94fd3fa32ba3b1ff4125', description: 'Some Description', active: true, locked: false })
+      @register_runner_response = Gitlab.register_runner('6337ff461c94fd3fa32ba3b1ff4125', description: 'Some Description', active: true, locked: false)
+    end
+
+    it 'gets the correct resource' do
+      expect(a_post('/runners')
+        .with(body: { token: '6337ff461c94fd3fa32ba3b1ff4125', description: 'Some Description', active: true, locked: false })).to have_been_made
+    end
+
+    it 'returns correct response for the runner registration' do
+      expect(@register_runner_response.token).to eq('6337ff461c94fd3fa32ba3b1ff4125')
+    end
+  end
+
+  describe '.delete_registered_runner' do
+    before do
+      stub_delete('/runners', 'empty').with(body: { token: '6337ff461c94fd3fa32ba3b1ff4125' })
+      Gitlab.delete_registered_runner('6337ff461c94fd3fa32ba3b1ff4125')
+    end
+
+    it 'gets the correct resource' do
+      expect(a_delete('/runners')
+        .with(body: { token: '6337ff461c94fd3fa32ba3b1ff4125' })).to have_been_made
+    end
+  end
+
+  describe '.verify_auth_registered_runner' do
+    before do
+      stub_post('/runners/verify', 'empty').with(body: { token: '6337ff461c94fd3fa32ba3b1ff4125' })
+      Gitlab.verify_auth_registered_runner('6337ff461c94fd3fa32ba3b1ff4125')
+    end
+
+    it 'gets the correct resource' do
+      expect(a_post('/runners/verify')
+        .with(body: { token: '6337ff461c94fd3fa32ba3b1ff4125' })).to have_been_made
+    end
+  end
 end
